@@ -2,10 +2,7 @@ package Promises;
 BEGIN {
   $Promises::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $Promises::VERSION = '0.90';
-}
-
+$Promises::VERSION = '0.91';
 # ABSTRACT: An implementation of Promises in Perl
 
 use strict;
@@ -16,7 +13,7 @@ our $Backend = 'Promises::Deferred';
 
 use Sub::Exporter -setup => {
     collectors => [ 'backend' => \'_set_backend' ],
-    exports    => [ qw[ deferred collect ]]
+    exports    => [qw[ deferred collect ]]
 };
 
 sub _set_backend {
@@ -40,7 +37,6 @@ sub collect {
     my $all_done  = $Backend->new;
     my $results   = [];
     my $remaining = scalar @promises;
-
     foreach my $i ( 0 .. $#promises ) {
         my $p = $promises[$i];
         $p->then(
@@ -57,7 +53,8 @@ sub collect {
         );
     }
 
-    $all_done->resolve(@$results) if $remaining == 0;
+    $all_done->resolve(@$results)
+        if $remaining == 0 and $all_done->is_in_progress;
 
     $all_done->promise;
 }
@@ -74,7 +71,7 @@ Promises - An implementation of Promises in Perl
 
 =head1 VERSION
 
-version 0.90
+version 0.91
 
 =head1 SYNOPSIS
 
@@ -199,7 +196,7 @@ should use the same event-loop. Module implementers should just use the
 Promises class directly:
 
     package MyClass;
-    use Promises qw(deferred collected);
+    use Promises qw(deferred collect);
 
 End users should specify which Deferred backend they wish to use. For
 instance if you are using AnyEvent, you can do:
@@ -316,7 +313,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Infinity Interactive, Inc..
+This software is copyright (c) 2014 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
